@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2005-2009 Alex Murray <murray.alex@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,26 +61,27 @@ enum {
 static gchar buffer[HDDTEMP_OUTPUT_BUFFER_LENGTH];
 
 static const gchar *hddtemp_plugin_query_hddtemp_daemon(GError **error) {
-    int sockfd;
-    ssize_t n = 1;
     guint output_length = 0;
     static gboolean first_run = TRUE;
-    gchar *pc;
 
     struct sockaddr_in address;
-    static GTimeVal previous_query_time;
-    GTimeVal current_query_time;
+    static gint64 previous_query_time;
+    gint64 current_query_time;
 
     if (first_run) {
         // initialise previous time
-        g_get_current_time(&previous_query_time);
+        previous_query_time = g_get_monotonic_time ();
     }
-    g_get_current_time(&current_query_time);
+    current_query_time = g_get_monotonic_time ();
 
     /* only actually query if more than 60 seconds has elapsed as
     hddtemp daemon will only actually send a new value if is > 60
     seconds */
-    if (first_run || current_query_time.tv_sec - previous_query_time.tv_sec > 60) {
+    if (first_run || current_query_time - previous_query_time > G_TIME_SPAN_MINUTE) {
+        int sockfd;
+        ssize_t n;
+        gchar *pc;
+
         previous_query_time = current_query_time;
 
         if ((sockfd = socket(AF_INET, SOCK_STREAM, 0)) == -1) {
