@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2005-2009 Alex Murray <murray.alex@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -400,7 +401,6 @@ static gdouble libsensors_plugin_get_sensor_value(const gchar *path,
     if (g_match_info_matches (m)) {
         const sensors_chip_name *found_chip;
         int feature;
-        int i;
 
         if ((found_chip = g_hash_table_lookup(hash_table, path)) != NULL) {
             gdouble value;
@@ -436,7 +436,7 @@ static gdouble libsensors_plugin_get_sensor_value(const gchar *path,
 }
 
 
-static GList *libsensors_plugin_init() {
+static GList *libsensors_plugin_init(void) {
     GError *err = NULL;
 
     /* compile the regular expressions */
