@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2005-2009 Alex Murray <murray.alex@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -293,10 +294,11 @@ static void prefs_dialog_row_activated(GtkTreeView *view, GtkTreePath *path, Gtk
 static void prefs_dialog_sensor_up_button_clicked(GtkButton *button, PrefsDialog *prefs_dialog) {
     GtkTreeModel *model;
     GtkTreeIter iter;
-    GtkTreePath *path;
 
     if (gtk_tree_selection_get_selected(prefs_dialog->sensors_applet->selection, &model, &iter)) {
         /* if has no prev node set up button insentive */
+        GtkTreePath *path;
+
         path = gtk_tree_model_get_path(model, &iter);
         if (gtk_tree_path_prev(path)) {
 
@@ -349,10 +351,12 @@ static void prefs_dialog_selection_changed(GtkTreeSelection *selection,
                                            PrefsDialog *prefs_dialog) {
 
     GtkTreeIter iter;
-    GtkTreePath *path;
     GtkTreeModel *model;
+
     /* if there is a selection with no children make config button sensitive */
     if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
+        GtkTreePath *path;
+
         if (!gtk_tree_model_iter_has_child(model, &iter)) {
             gtk_widget_set_sensitive(GTK_WIDGET(prefs_dialog->sensor_config_button), TRUE);
         } else {
@@ -452,10 +456,7 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
     /* if no SensorsList's have been created, this is because
        we haven't been able to access any sensors */
     if (sensors_applet->sensors == NULL) {
-        GtkWidget *label;
-        GtkWidget *content_area;
-        label = gtk_label_new(_("No sensors found!"));
-        content_area = gtk_dialog_get_content_area (prefs_dialog->dialog);
+        GtkWidget *label = gtk_label_new(_("No sensors found!"));
         gtk_box_pack_start (GTK_BOX(content_area), label, FALSE, FALSE, 0);
         return;
     }
